@@ -31,7 +31,7 @@ import textwrap
 import tokenize
 
 
-__version__ = '0.4'
+__version__ = '0.4.1'
 
 
 try:
@@ -185,11 +185,9 @@ def format_docstring(indentation, docstring,
                                  wrap_length=summary_wrap_length,
                                  initial_indent=initial_indent,
                                  subsequent_indent=indentation).lstrip(),
-            description=wrap_description(
-                '\n'.join([indent_non_indented(l, indentation).rstrip()
-                           for l in description.splitlines()]),
-                indentation=indentation,
-                wrap_length=description_wrap_length),
+            description=wrap_description(description,
+                                         indentation=indentation,
+                                         wrap_length=description_wrap_length),
             post_description=('\n' if post_description_blank else ''),
             indentation=indentation)
     else:
@@ -288,12 +286,19 @@ def wrap_summary(summary, initial_indent, subsequent_indent, wrap_length):
 def wrap_description(text, indentation, wrap_length):
     """Return line-wrapped description text.
 
-    We only wrap simple descriptions. We leave multi-paragraph and bulleted
-    lists alone.
+    We only wrap simple descriptions. We leave doctests, multi-paragraph text,
+    and bulleted lists alone.
 
     """
+    # Do modify doctests at all.
+    if '>' in text:
+        return text
+
+    text = '\n'.join([indent_non_indented(l, indentation).rstrip()
+                      for l in text.splitlines()])
+
     # Ignore possibly complicated cases.
-    if (not wrap_length or
+    if (wrap_length <= 0 or
             re.search(r'\n\s*\n', text) or
             re.search(r'[0-9]\.', text) or
             re.search(r'[\-*:]', text)):
